package negocio;

import java.awt.Point;
import java.awt.Polygon;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.EventListener;

import presentacion.Ventana;

/**
 * Clase controladora que gestiona las peticiones de la interfaz.
 * 
 * @author Santiago de la Parte Flrez
 */
public class Controlador extends MouseAdapter implements EventListener, ActionListener, ItemListener {
	private Ventana vista;
	
	private Padron padronConsulta;
	
	// Formateador de valores decimales
	private DecimalFormat formateador = new DecimalFormat("###.##");
	
	// Descripciones de Distritos y Zona Estadsticas
	private String[] textsDto;
	private String[] textsZE;
	
	// Secciones de cada Distrito
	private ArrayList<String[]> seccionesDto;
	private String[] secDto0 = {"Seleccionar Distrito"};
	private String[] secDto1 = {"Todas", "1", "3", "5", "6", "7"};
	private String[] secDto2 = {"Todas", "1", "2", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", "14", "15", "17", "19"};
	private String[] secDto3 = {"Todas", "1", "2", "3", "4", "5", "7", "8", "9"};
	private String[] secDto4 = {"Todas", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", "14", "15", "16", "17", "18", "20", "21", "22", "23", "24", "25", "26", "27", "28", "29", "30", "32", "33", "34", "35", "36", "37", "38", "39", "40", "41"};
	private String[] secDto5 = {"Todas", "1", "2", "3", "4", "6", "7"};
	private String[] secDto6 = {"Todas", "1", "2", "3", "5", "6", "7", "8", "9", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27", "28", "29", "30", "31", "32", "33", "34", "36", "37", "38", "39"};
	private String[] secDto7 = {"Todas", "1", "3", "4", "5", "6", "7", "8", "9", "10", "11", "13", "14", "15", "16", "17", "18", "19", "20", "21"};
	private String[] secDto8 = {"Todas", "1", "2", "4", "5", "6", "9", "10", "12", "13", "14", "15", "16", "17", "18", "20", "21", "23", "24", "25", "26", "27", "28", "30", "31", "32", "33", "34", "35", "36", "37", "38", "39", "40", "41"};
	private String[] secDto9 = {"Todas", "1", "2", "3", "4", "6", "7", "9", "10", "11", "12"};
	private String[] secDto10 = {"Todas", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22", "24", "25", "26", "27", "28", "29", "30", "31", "32", "33", "34", "35", "36", "37", "38", "39", "40", "41", "42", "43", "44", "45", "46", "47", "48", "49", "50", "51", "52", "53"};
	private String[] secDto11 = {"Todas", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "12", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27", "28", "29", "30", "31", "32", "33", "34", "35", "36", "37", "38", "39", "40", "41", "42"};
	private String[] secDto12 = {"Todas", "1", "2", "3", "4"};
	
	// Valores por defecto
	private String sexoVA = "Todos";
	private String edadVA = "Todos";
	private String estudiosVA = "Todos";
	private String procedenciaVA = "Todos";
	
	// ltimpos parmetros consultados
	private String ulVADto1 = "";
	private String ulVADto2 = "";
	private String ulVAZE1 = "";
	private String ulVAZE2 = "";
	private String ulDtoinfo = "";
	private String ulDtocomp = "";
	private String ulZEinfo = "";
	private String ulZEcomp = "";
	
	/**
	 * Creacin del controlador con la clase principal del applet como parmetro.
	 * 
	 * @param vista
	 */
	public Controlador (Ventana vista) {
		this.vista = vista;
		this.padronConsulta = new Padron();
		
		textsZE = new String[48];
		textsZE[0] = "<html>ZONA 1. Ro Pisuerga (margen izdo.), Pza. del Poniente, Pza. de la Rinconada, C/ San Benito, C/ Francisco Zarandona, C/ Conde Ansrez, C/ Ra Oscura, C/ Leopoldo Cano, C/ Macas Picavea, Pza. de la Libertad, C/ Bajada de la Libertad, C/ Cnovas del Castillo, C/ Nuez de Arce, C/ Alonso Pesquera, C/ Jos Mara Lacort, Pza. Espaa, Pza. Madrid, C/ Gamazo, Pza. Coln, C/ Acera de Recoletos, Pza. Zorrilla, Paseo Zorrilla, C/ San Ildefonso, Pza. Teneras, Paseo Isabel la Catlica, Ro Pisuerga (margen izdo.).</html>";
		textsZE[1] = "<html>ZONA 2. Calle Gamazo, Plaza Madrid, Plaza Espaa, Calle Jos Mara Lacort, Plaza Cruz Verde, Calle Labradores, Calle Estacin, Plaza Coln, Calle Gamazo.</html>";
		textsZE[2] = "<html>ZONA 3. C/ Leopoldo Cano, C/ Macas Picavea, Plaza de la Libertad, C/ Bajada de la Libertad, C/ Cnovas del Castillo, C/ Nuez de Arce, Plaza Colegio de Santa Cruz, C/ Merced, C/ Maldonado, Plaza de San Juan, C/ Huelgas, C/ Alamillos, Avenida Ramn y Cajal, C/ Prado, C/ Piedad, C/ Marqus del Duero, C/ Esgueva, C/ Fernando V, Plaza del Rosario, C/ San Juan de Dios, C/ Leopoldo Cano.</html>";
		textsZE[3] = "<html>ZONA 4. Avenida Ramn y Cajal, Calle Prado, Calle Piedad, Calle Marqus del Duero, Calle Esgueva, Calle Angustias, Plaza San Pablo, Calle Cardenal Torquemada, Calle Rondilla de Santa Teresa, Calle Torrecilla, Calle Padilla, Avenida Ramn y Cajal.</html>";
		textsZE[4] = "<html>ZONA 5. Ro Pisuerga (margen izquierdo), Calle Rondilla de Santa Teresa, Calle Cardenal Torquemada, Plaza San Pablo, Calle Esteban Garca Chico, Calle San Quirce, Ro Pisuerga (margen izquierdo).</html>";
		textsZE[5] = "<html>ZONA 6. Ro Pisuerga (margen izquierdo), Calle San Quirce, Calle Esteban Garca Chico, Plaza San Pablo, Calle Angustias, Calle Fernando V, Plaza del Rosario, Calle San Juan de Dios, Calle Leopoldo Cano, Calle Ra Oscura, Calle Conde Ansrez, Calle Francisco Zarandona, Calle San Benito, Plaza Rinconada, Plaza Poniente, Ro Pisuerga (margen izquierdo).</html>";
		textsZE[6] = "<html>ZONA 7. Calle Labradores, Plaza Cruz Verde, Calle Don Sancho, Calle Santa Luca, Calle Nicasio Prez, Calle Unin, Calle Va, Calle Estacin, Calle Labradores.</html>";
		textsZE[7] = "<html>ZONA 8. Plaza Cruz Verde, Calle Alonso Pesquera, Plaza Colegio de Santa Cruz, Calle Merced, Calle Maldonado, Plaza San Juan, Calle Nicasio Prez, Calle Santa Luca, Calle Don Sancho, Plaza Cruz Verde.</html>";
		textsZE[8] = "<html>ZONA 9. Calle Santa Luca, Plaza Luis Braille, Calle Gabriel y Galn, Paseo del Cauce (ro Esgueva), Calle Va, Calle Unin, Calle Nicasio Prez, Calle Santa Luca.</html>";
		textsZE[9] = "<html>ZONA 10. Calle Plvora, Plaza Luis Braille, Calle Gabriel y Galn, Paseo del Cauce (ro Esgueva), Calle Nochevieja, Paseo Prado de la Magdalena, Calle Alamillos, Calle Plvora.</html>";
		textsZE[10] = "<html>ZONA 11. Calle Santa Clara, Avenida de Palencia, Paseo del Cauce (ro Esgueva), Calle Nochevieja, Paseo Prado de la Magdalena, Avenida Ramn y Cajal, Calle Padilla, Calle Torrecilla, Calle Santa Clara.</html>";
		textsZE[11] = "<html>ZONA 12. Ro Pisuerga (margen izquierdo), Paseo del Cauce (ro Esgueva), Calle Siglo de Oro, Calle Portillo de Balboa, Calle Soto, Calle Olmo, Calle Linares, Calle Portillo de Balboa, Calle Rondilla de Santa Teresa, Ro Pisuerga (margen izquierdo).</html>";
		textsZE[12] = "<html>ZONA 13. Calle Padre Jos Acosta, Calle Mieses, Avenida Jos Luis Arrese, Calle Po del Ro Hortega, Avenida Vicente Mortes, Calle Mieses, Avenida Gijn, Ro Pisuerga (margen derecho), Avenida Vicente Mortes, Avenida Salamanca, Calle Padre Jos Acosta.</html>";
		textsZE[13] = "<html>ZONA 14. Avenida Salamanca, Avenida Vicente Mortes, Ro Pisuerga (margen derecho), Avenida Sanchez Arjona, Calle Joaqun Velasco Martn, Avenida Jos Luis Arrese, Avenida Salamanca.</html>";
		textsZE[14] = "<html>ZONA 15. Avenida Salamanca, Avenida Jos Luis Arrese, Calle Joaqun Velasco Martn, Avenida Sanchez Arjona, Ro Pisuerga (margen derecho), Calle Puente Colgante, Avenida Salamanca.</html>";
		textsZE[15] = "<html>ZONA 16. Ro Pisuerga (margen izquierdo), Paseo Isabel la Catlica, Plaza Teneras, Calle San Ildefonso, Paseo Zorrilla, Calle Puente Colgante, Calle Magallanes, Calle Tres Amigos, Avenida Reyes Catlicos, Plaza Amrica, Ro Pisuerga (margen izquierdo).</html>";
		textsZE[16] = "<html>ZONA 17. Paseo Zorrilla, Plaza Zorrilla, Calle Acera de Recoletos, Plaza Coln, Calle Estacin, Avenida Segovia, Paseo Farnesio, Calle Argales, Calle General Shelly, Paseo Arco de Ladrillo, Calle Puente Colgante, Paseo Zorrilla.</html>";
		textsZE[17] = "<html>ZONA 18. Calle Salud, Paseo del Cauce (ro Esgueva), Paseo Juan Carlos I, Calle San Isidro, Calle Salud.</html>";
		textsZE[18] = "<html>ZONA 19. Paseo del Cauce (ro Esgueva), Calle Nochevieja, Plaza Aviador Gmez del Barco, lnea ferrocarril Madrid-Irn, Carretera de Renedo, Ronda Este, Ro Esgueva, Paseo del Cauce (ro Esgueva).</html>";
		textsZE[19] = "<html>ZONA 20. Paseo del Cauce (ro Esgueva), Camino Cementerio, Ronda Este, lnea ferrocarril Madrid-Irn, Plaza Aviador Gmez del Barco, Calle Nochevieja, Paseo del Cauce (ro Esgueva).</html>";
		textsZE[20] = "<html>ZONA 21. Paseo del Cauce (ro Esgueva), Avenida Santander, Calle Costa Brava, Ro Pisuerga (margen izquierdo), fin del Trmino Municipal, Ro Esgueva, Ronda Este, Carretera de Renedo, lnea ferrocarril Madrid-Irn, Ronda Este, Camino Cementerio,  Paseo del Cauce (ro Esgueva).</html>";
		textsZE[21] = "<html>ZONA 22. Paseo del Cauce (ro Esgueva), Ro Pisuerga (margen izquierdo), Calle Costa Brava, Avenida Santander, Paseo del Cauce (ro Esgueva).</html>";
		textsZE[22] = "<html>ZONA 23. Avenida Gijn, fin del Trmino Municipal (oeste), Ronda Oeste, Camino Virgen de la Merced,  Calle Acera del  Mirador, Calle Barco de San Vicente, Subida Fuente el Sol, Calle Costanilla, Calle Troja, Calle Brezo, Avenida de Burgos, Nacional 620, Ro Pisuerga (margen derecho), Plaza San Bartolom, Avenida Gijn.</html>";
		textsZE[23] = "<html>ZONA 24. Autova Puente Colgante, fin del Trmino Municipal (oeste), Avenida Gijn, Calle Morena, Calle Mieses, Calle Padre Jos Acosta, Avenida Salamanca, Autova Puente Colgante.</html>";
		textsZE[24] = "<html>ZONA 25. Avenida Salamanca, fin del Trmino Municipal (sur-oeste), Autova Puente Colgante, Avenida Salamanca.</html>";
		textsZE[25] = "<html>ZONA 26. Avenida Salamanca, Calle Puente Colgante, Ro Pisuerga (margen derecho), Calle Ecuador, Calle Colombia, Calle Chile, Ro Pisuerga (margen derecho), Avenida Salamanca.</html>";
		textsZE[26] = "<html>ZONA 27. Calle Chile, Calle Colombia, Calle Ecuador, Ro Pisuerga (margen derecho), Calle Chile.</html>";
		textsZE[27] = "<html>ZONA 28. Ro Pisuerga (margen izquierdo), Paseo de Zorrilla, Carretera de Rueda, Calle Olimpo, lnea ferrocarril Madrid-Irn, Futura Ronda Exterior Sur, Ro Pisuerga (margen izquierdo).</html>";
		textsZE[28] = "<html>ZONA 29. Carretera de Rueda, Calle Final, Calle Doctor Moreno, Calle Mota, Calle Espanta, Carretera Rueda.</html>";
		textsZE[29] = "<html>ZONA 30. Calle Olimpo, Carretera de Rueda, Calle Final, Calle Doctor Moreno, Calle Mota, Calle Espanta, lnea ferrocarril Madrid-Irn, Calle Olimpo.</html>";
		textsZE[30] = "<html>ZONA 31. Ro Pisuerga (margen izquierdo), Calle Juan Altisent, Paseo Zorrilla, Ro Pisuerga (margen izquierdo).</html>";
		textsZE[31] = "<html>ZONA 32. Ro Pisuerga (margen izquierdo), Calle Puente Colgante, Paseo Arco de Ladrillo, lnea ferrocarril Madrid-Irn, Camino de la Esperanza, Paseo de Zorrilla, Calle Juan Altisent, Ro Pisuerga (margen izquierdo).</html>";
		textsZE[32] = "<html>ZONA 33. Ro Pisuerga (margen izquierdo), Plaza Amrica, Avenida Reyes Catlicos, Calle Tres Amigos, Paseo Zorrilla, Calle Magallanes, Calle Puente Colgante, Ro Pisuerga (margen izquierdo).</html>";
		textsZE[33] = "<html>ZONA 34. Paseo Zorrilla, Camino de la Esperanza, lnea ferrocarril Madrid-Irn, Calle Espanta, Paseo Zorrilla.</html>";
		textsZE[34] = "<html>ZONA 35. Lnea ferrocarril Madrid-Irn,  Paseo Arco de Ladrillo, Avenida Madrid, Futura Ronda Exterior Sur, lnea ferrocarril Madrid-Irn.</html>";
		textsZE[35] = "<html>ZONA 36. Paseo Arco de Ladrillo, Calle General Shelly, Calle Argales, Paseo Farnesio, Avenida Segovia, lnea ferrocarril Madrid-Irn, Calle San Isidro, Paseo Juan Carlos I, Calle General Shelly, Calle Arca Real, Calle Sargento Provisional, Calle Embajadores, Paseo Juan Carlos I, Paseo Arco de Ladrillo.</html>";
		textsZE[36] = "<html>ZONA 37. Paseo Juan Carlos I, Avenida Fernando Ferreiro, Calle Pajarillos, Calle Villabaez, Calle Santa Eulalia, Calle Nardo, Calle Geranio, Calle Flor, Calle Petunia, Calle Lilas, Calle Azalea, Calle Flor de Acebo, Calle Villabaez, Ronda Este, Ro Esgueva, fin del Trmino Municipal, Avenida de Madrid, Paseo Juan Carlos I.</html>";
		textsZE[37] = "<html>ZONA 38. Paseo Juan Carlos I, Camino Martillete (Ro Esgueva), Ronda Este, Calle Villabaez, Calle Pajarillos, Avenida Fernando Ferreiro, Paseo Juan Carlos I.</html>";
		textsZE[38] = "<html>ZONA 39. Calle Villabaez, Calle Flor de Acebo, Calle Azalea, Calle Lilas, Calle Petunia, Calle Flor, Calle Geranio, Calle Nardo, Calle Santa Eulalia, Calle Villabaez.</html>";
		textsZE[39] = "<html>ZONA 40. Comprende las Entidades de Poblacin de La Overuela y de Navabuena.</html>";
		textsZE[40] = "<html>ZONA 41. Comprende la Entidad de Poblacin del Pinar de Antequera.</html>";
		textsZE[41] = "<html>ZONA 42. Comprende la Entidad de Poblacin de Puente Duero-Esparragal.</html>";
		textsZE[42] = "<html>ZONA 8B. Calle Huelgas, Calle Plvora, Plaza Luis Braille, Calle Santa Luca, Calle Nicasio Prez, Calle Huelgas.</html>";
		textsZE[43] = "<html>ZONA 12B. Calle Portillo de Balboa, Calle Linares, Calle Olmo, Calle Soto, Calle Portillo de Balboa, Paseo del Cauce (ro Esgueva), Avenida de Palencia, Calle Santa Clara, Calle Gondomar, Calle Portillo de Balboa.</html>";
		textsZE[44] = "<html>ZONA 15B. Calle Mieses, Avenida Vicente Mortes, Calle Po del Ro Hortega, Avenida Jos Luis Arrese, Calle Mieses.</html>";
		textsZE[45] = "<html>ZONA 24B. Calle Morena, Avenida Gijn, Calle Mieses, Calle Morena.</html>";
		textsZE[46] = "<html>ZONA 36B. Avenida Madrid, Paseo Juan Carlos I, Calle Embajadores, Calle Sargento Provisional, Calle Arca Real, Calle General Shelly, Paseo Juan Carlos I, Avenida Soria, fin del Trmino Municipal, Avenida Madrid.</html>";
		textsZE[47] = "<html>Seleccione una Zona Estadstica.</html>";
		
		textsDto = new String[13];
		textsDto[0] = "<html>DISTRITO 1. Ro Pisuerga (margen izquierdo), Plaza del Poniente, Plaza de la Rinconada, Calle San Benito, Calle Francisco Zarandona, Calle del Val, Calle Alarcn, Calle Quiones, Calle Duque de la Victoria, Calle Miguel Iscar, Plaza Zorrilla, Paseo Zorrilla, Calle San Ildefonso, Plaza Teneras, Paseo Isabel la Catlica, Ro Pisuerga (margen izquierdo).</html>";
		textsDto[1] = "<html>DISTRITO 2. Ro Pisuerga (margen izquierdo), Paseo Isabel la Catlica, Plaza Teneras, Calle San Ildefonso, Paseo Zorrilla, Plaza Zorrilla, Calle Miguel Iscar, Plaza Madrid, Calle Gamazo, Plaza Coln, Calle Estacin del Norte, Calle Recondo, Calle Puente Colgante, Ro Pisuerga (margen izquierdo).</html>";
		textsDto[2] = "<html>DISTRITO 3. Calle Gamazo, Plaza Madrid, Plaza Espaa, Calle Jos Mara Lacort, Plaza Cruz Verde, Calle Labradores, Calle Estacin, Plaza Coln, Calle Gamazo.</html>";
		textsDto[3] = "<html>DISTRITO 4. Calle Recondo, Calle Estacin del Norte, Plaza Coln, Calle Estacin, Calle San Isidro, Avenida de Soria, fin del Trmino Municipal (este), Avenida de Madrid, Paseo Arco de Ladrillo, Calle Recondo.</html>";
		textsDto[4] = "<html>DISTRITO 5. Calle del Val, Calle Alarcn, Calle Quiones, Calle Duque de la Victoria, Plaza Espaa, Calle Jos Mara Lacort, Plaza Cruz Verde, Calle Alonso Pesquera, Plaza Colegio de Santa Cruz, Calle Librera, Plaza de la Universidad, Calle Duque de Lerma, Calle Esgueva, Calle Fernando V, Plaza del Rosario, Calle San Juan de Dios, Calle Leopoldo Cano, Calle Ra Oscura, Calle Conde Ansurez, Calle del Val.</html>";
		textsDto[5] = "<html>DISTRITO 6. Calle Labradores, Plaza Cruz Verde, Calle Don Sancho, Calle Santa Luca, Plaza Luis Braille, Calle Gabriel y Galn, Paseo del Cauce (Ro Esgueva), Camino del Martillete (Ro Esgueva), fin del Trmino Municipal (este), Avenida de Soria, Calle San Isidro, Calle Estacin, Calle Labradores.</html>";
		textsDto[6] = "<html>DISTRITO 7. Calle Alonso Pesquera, Plaza Colegio de Santa Cruz, Calle Librera, Plaza de la Universidad, Calle Duque de Lerma, Calle Marqus del Duero, Calle Paraso, Avenida Ramn y Cajal, Paseo Prado de la Magdalena, Calle Nochevieja, Paseo del Cauce (Ro Esgueva), Camino del Cementerio, Ronda Este, Ferrocarril Madrid-Irn, Carretera de Renedo, Ronda Este, Camino del Martillete (Ro Esgueva), Paseo del Cauce (Ro Esgueva), Calle Gabriel y Galn, Plaza Luis Braille, Calle Santa Luca, Calle Don Sancho, Plaza Cruz Verde, Calle Alonso Pesquera.</html>";
		textsDto[7] = "<html>DISTRITO 8. Ro Pisuerga (margen izquierdo), fin del Trmino Municipal (norte), Ro Esgueva, Camino del Martillete (Ro Esgueva), Ronda Este, Carretera de Renedo, Ferrocarril Madrid-Irn, Ronda Este, Camino del Cementerio, Paseo del Cauce (Ro Esgueva), Calle Nochevieja, Paseo Prado de la Magdalena, Avenida Ramn y Cajal, Calle Padilla, Calle Torrecilla, Calle Gondomar, Calle Rondilla de Santa Teresa, Ro Pisuerga (margen izquierdo).</html>";
		textsDto[8] = "<html>DISTRITO 9. Ro Pisuerga (margen izquierdo), Calle Rondilla de Santa Teresa, Calle Gondomar, Calle Torrecilla, Calle Padilla, Avenida Ramn y Cajal, Calle Paraso, Calle Marqus del Duero,  Calle Esgueva, Calle Fernando V, Plaza Rosario, Calle San Juan de Dios, Calle Leopoldo Cano, Calle Ra Oscura, Calle Conde Ansurez, Calle Francisco Zarandona, Calle San Benito, Plaza de la Rinconada, Plaza del Poniente, Ro Pisuerga (margen izquierdo).</html>";
		textsDto[9] = "<html>DISTRITO 10. Ro Pisuerga (margen derecho), fin del Trmino Municipal (oeste), Ronda Oeste, Camino Virgen de la Merced,  Calle Acera del  Mirador, Calle Barco de San Vicente, Subida Fuente el Sol, Calle Costanilla, Calle Troja, Calle Brezo, Avenida de Burgos, Nacional 620, Ro Pisuerga (margen derecho).</html>";
		textsDto[10] = "<html>DISTRITO 11. Ro Pisuerga (margen izquierdo), Calle del Puente Colgante, Paseo Arco de Ladrillo, Avenida de Madrid, Futura Ronda Exterior Sur, Ro Pisuerga (margen izquierdo).</html>";
		textsDto[11] = "<html>DISTRITO 12. Entidades de Poblacin de: Navabuena, La Overuela, Pinar de Antequera y Puente Duero-Esparragal.</html>";
		textsDto[12] = "<html>Seleccione un Distrito.</html>";
		
		seccionesDto = new ArrayList<String[]>();
		seccionesDto.add(0, secDto1);
		seccionesDto.add(1, secDto2);
		seccionesDto.add(2, secDto3);
		seccionesDto.add(3, secDto4);
		seccionesDto.add(4, secDto5);
		seccionesDto.add(5, secDto6);
		seccionesDto.add(6, secDto7);
		seccionesDto.add(7, secDto8);
		seccionesDto.add(8, secDto9);
		seccionesDto.add(9, secDto10);
		seccionesDto.add(10, secDto11);
		seccionesDto.add(11, secDto12);
	}
	
	/**
	 * Captura de los clicks de ratn. Sirve para configurar la vista en funcin de los elementos seleccionados
	 * en el mapa.
	 */
	public void mouseClicked(MouseEvent e) {
		if (vista.isDistritoPanel(e.getComponent())) {
	        Point p = e.getPoint();  
	        
	        Polygon[] polys = vista.getDistritoPolygons();
	        for(int j = 0; j < polys.length; j++) {
	            if(polys[j].contains(p)) {
	            	if (vista.getDistritoClicked()==j) {
	            		vista.setDistritoClicked(-1);
	            		vista.setDesplegableSeccion(secDto0);
	            		vista.setComboGralDtoValor(0);
	            		vista.setComboGralDtoEnabled(false);
	            	} else {
	            		vista.setDistritoClicked(j);
	            		vista.setComboGralDtoValor(0);
	            		vista.setComboGralDtoEnabled(true);
	            		vista.setDesplegableSeccion(seccionesDto.get(j));
	            	}
	            	vista.repaint();
	                vista.setDescripcionDtoLabel(textsDto[j]);
	                return;
	            }
	        }
		}
		
		if (vista.isZonaEstPanel(e.getComponent())) {
	        Point p = e.getPoint();  
	        Polygon[] polys = vista.getZonaEstPolygons();
	        for(int j = 0; j < polys.length; j++) {
	            if(polys[j].contains(p)) {
	            	if (vista.getZonaEstClicked()==j) {
	            		vista.setZonaEstClicked(-1);
	            		vista.setComboGralZEValor(0);
	            		vista.setComboGralZEEnabled(false);
	            	} else {
	            		vista.setZonaEstClicked(j);
	            		vista.setComboGralZEValor(0);
	            		vista.setComboGralZEEnabled(true);
	            	}
	            	vista.repaint();
	                vista.setDescripcionZELabel(textsZE[j]);
	                return;
	            }
	        }
		}
    }
    
	/**
	 * Captura los movimientos de ratn. Sirve para configurar la vista en funcin del elemento del mapa
	 * sobre el que se sita el ratn.
	 */
    public void mouseMoved(MouseEvent e) {
    	if (vista.isDistritoPanel(e.getComponent())) {
			Point p = e.getPoint();  
			Polygon[] polys = vista.getDistritoPolygons();
			vista.setDistritoEncima(-1);
			for(int j = 0; j < polys.length; j++) {
				if(polys[j].contains(p)) {
					vista.setDistritoEncima(j);
					vista.setDescripcionDtoLabel(textsDto[j]);
					vista.repaint();
					return;  
				}
			}
			vista.setDistritoEncima(-1);
			if (vista.getDistritoClicked() == -1) {
				vista.setDescripcionDtoLabel(textsDto[12]);
			} else {
				vista.setDescripcionDtoLabel(textsDto[vista.getDistritoClicked()]);
			}
			vista.repaint();
			return;
    	}
    	
    	if (vista.isZonaEstPanel(e.getComponent())) {
			Point p = e.getPoint();  
			Polygon[] polys = vista.getZonaEstPolygons();
			vista.setZonaEstEncima(-1);
			for(int j = 0; j < polys.length; j++) {
				if(polys[j].contains(p)) {
					vista.setZonaEstEncima(j);
					vista.setDescripcionZELabel(textsZE[j]);
					vista.repaint();
					return;  
				}
			}
			vista.setZonaEstEncima(-1);
			if (vista.getZonaEstClicked() == -1) {
				vista.setDescripcionZELabel(textsZE[47]);
			} else {
				vista.setDescripcionZELabel(textsZE[vista.getZonaEstClicked()]);
			}
			vista.repaint();
			return;
    	}
    }
    
    /**
     * Captura la salida del ratn de un elemento. Sirve para dejar de controlar eventos en determinadas ocasiones.
     */
    public void mouseExited(MouseEvent e) {
		if (vista.isDistritoPanel(e.getComponent())) {
			vista.setDistritoEncima(-1);
			if (vista.getDistritoClicked() == -1) {
				vista.setDescripcionDtoLabel(textsDto[12]);
			} else {
				vista.setDescripcionDtoLabel(textsDto[vista.getDistritoClicked()]);
			}
			vista.repaint();
			return;
		}
		
		if (vista.isZonaEstPanel(e.getComponent())) {
			vista.setZonaEstEncima(-1);
			if (vista.getZonaEstClicked() == -1) {
				vista.setDescripcionZELabel(textsZE[47]);
			} else {
				vista.setDescripcionZELabel(textsZE[vista.getZonaEstClicked()]);
			}
			vista.repaint();
			return;
		}
    }

    /**
     * Captura una accin sobre un botn. Sirve para controlar las solicitudes de consulta sobre los botones de la
     * interfaz.
     */
	public void actionPerformed(ActionEvent e) {
		// Si es el botn de Consulta en la pestaa Distrito
		if (vista.isDistritoConsultaButton(e.getSource())) {
			String tipo = vista.getDistritoTipoConsulta();
			int seccion = -1;
			ResultadoConsulta miResultado;
			if (!vista.getDistritoSeccion().equals("Todas"))
				seccion = Integer.parseInt(vista.getDistritoSeccion());
			switch (tipo) {
			case "Procedencia (Nac.)":
				miResultado = padronConsulta.consultaProcedencia((vista.getDistritoClicked()+1), seccion, null, vista.getDistritoSexo(),
						vista.getDistritoEstudios(), vista.getDistritoEdad(), Padron.TipoProcedencia.NACIONAL);
				vista.setChartConsultaDto(miResultado.getChart());
				vista.setTextoConsultaDto("<html>Distrito "+(vista.getDistritoClicked()+1)+"<br/>" +
						"Seccin: "+vista.getDistritoSeccion()+"<br/>" +
						"Distribucin: "+tipo+"<br/>" +
						"Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)<br/>" +
						"Sexo: "+vista.getDistritoSexo()+"<br/>" +
						"Estudios: "+vista.getDistritoEstudios()+"<br/>" +
						"Edad: "+vista.getDistritoEdad()+"</html>");
				break;
			case "Procedencia (Extr.)":
				miResultado = padronConsulta.consultaProcedencia((vista.getDistritoClicked()+1), seccion, null, vista.getDistritoSexo(),
						vista.getDistritoEstudios(), vista.getDistritoEdad(), Padron.TipoProcedencia.EXTRANJERA);
				vista.setChartConsultaDto(miResultado.getChart());
				vista.setTextoConsultaDto("<html>Distrito "+(vista.getDistritoClicked()+1)+"<br/>" +
						"Seccin: "+vista.getDistritoSeccion()+"<br/>" +
						"Distribucin: "+tipo+"<br/>" +
						"Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)<br/>" +
						"Sexo: "+vista.getDistritoSexo()+"<br/>" +
						"Estudios: "+vista.getDistritoEstudios()+"<br/>" +
						"Edad: "+vista.getDistritoEdad()+"</html>");
				break;
			case "Estudios":
				miResultado = padronConsulta.consultaEstudios((vista.getDistritoClicked()+1), seccion, null, vista.getDistritoSexo(),
						vista.getDistritoProcedencia(), vista.getDistritoEdad());
				vista.setChartConsultaDto(miResultado.getChart());
				vista.setTextoConsultaDto("<html>Distrito "+(vista.getDistritoClicked()+1)+"<br/>" +
						"Seccin: "+vista.getDistritoSeccion()+"<br/>" +
						"Distribucin: "+tipo+"<br/>" +
						"Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)<br/>" +
						"Sexo: "+vista.getDistritoSexo()+"<br/>" +
						"Procedencia: "+vista.getDistritoProcedencia()+"<br/>" +
						"Edad: "+vista.getDistritoEdad()+"</html>");
				break;
			case "Sexo":
				miResultado = padronConsulta.consultaSexo((vista.getDistritoClicked()+1), seccion, null, vista.getDistritoProcedencia(),
						vista.getDistritoEstudios(), vista.getDistritoEdad());
				vista.setChartConsultaDto(miResultado.getChart());
				vista.setTextoConsultaDto("<html>Distrito "+(vista.getDistritoClicked()+1)+"<br/>" +
						"Seccin: "+vista.getDistritoSeccion()+"<br/>" +
						"Distribucin: "+tipo+"<br/>" +
						"Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)<br/>" +
						"Procedencia: "+vista.getDistritoProcedencia()+"<br/>" +
						"Estudios: "+vista.getDistritoEstudios()+"<br/>" +
						"Edad: "+vista.getDistritoEdad()+"</html>");
				break;
			case "Edad":
				miResultado = padronConsulta.consultaEdad((vista.getDistritoClicked()+1), seccion, null, vista.getDistritoSexo(),
						vista.getDistritoProcedencia(), vista.getDistritoEstudios());
				vista.setChartConsultaDto(miResultado.getChart());
				vista.setTextoConsultaDto("<html>Distrito "+(vista.getDistritoClicked()+1)+"<br/>" +
						"Seccin: "+vista.getDistritoSeccion()+"<br/>" +
						"Distribucin: "+tipo+"<br/>" +
						"Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)<br/>" +
						"Sexo: "+vista.getDistritoSexo()+"<br/>" +
						"Procedencia: "+vista.getDistritoProcedencia()+"<br/>" +
						"Estudios: "+vista.getDistritoEstudios()+"</html>");
				break;
			default:
			}
		vista.repaint();
		return;
		}
		// Si es el botn de Consulta en la pestaa Zona Estadstica
		if (vista.isZonaEstConsultaButton(e.getSource())) {
			String tipo = vista.getZonaEstTipoConsulta();
			ResultadoConsulta miResultado;
			String zonaEst = null;
			switch (vista.getZonaEstClicked()+1) {
			case 43:
				zonaEst = "8B";
				break;
			case 44:
				zonaEst = "12B";
				break;
			case 45:
				zonaEst = "15B";
				break;
			case 46:
				zonaEst = "24B";
				break;
			case 47:
				zonaEst = "36B";
				break;
			default:
				zonaEst = Integer.toString(vista.getZonaEstClicked()+1);
			}
			switch (tipo) {
			case "Procedencia (Nac.)":
				miResultado = padronConsulta.consultaProcedencia(-1, -1, zonaEst, vista.getZonaEstSexo(),
						vista.getZonaEstEstudios(), vista.getZonaEstEdad(), Padron.TipoProcedencia.NACIONAL);
				vista.setChartConsultaZE(miResultado.getChart());
				vista.setTextoConsultaZE("<html>Zona "+zonaEst+"<br/>" +
						"Distribucin: "+tipo+"<br/>" +
						"Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)<br/>" +
						"Sexo: "+vista.getZonaEstSexo()+"<br/>" +
						"Estudios: "+vista.getZonaEstEstudios()+"<br/>" +
						"Edad: "+vista.getZonaEstEdad()+"</html>");
				break;
			case "Procedencia (Extr.)":
				miResultado = padronConsulta.consultaProcedencia(-1, -1, zonaEst, vista.getZonaEstSexo(),
						vista.getZonaEstEstudios(), vista.getZonaEstEdad(), Padron.TipoProcedencia.EXTRANJERA);
				vista.setChartConsultaZE(miResultado.getChart());
				vista.setTextoConsultaZE("<html>Zona "+zonaEst+"<br/>" +
						"Distribucin: "+tipo+"<br/>" +
						"Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)<br/>" +
						"Sexo: "+vista.getZonaEstSexo()+"<br/>" +
						"Estudios: "+vista.getZonaEstEstudios()+"<br/>" +
						"Edad: "+vista.getZonaEstEdad()+"</html>");
				break;
			case "Estudios":
				miResultado = padronConsulta.consultaEstudios(-1, -1, zonaEst, vista.getZonaEstSexo(),
						vista.getZonaEstProcedencia(), vista.getZonaEstEdad());
				vista.setChartConsultaZE(miResultado.getChart());
				vista.setTextoConsultaZE("<html>Zona "+zonaEst+"<br/>" +
						"Distribucin: "+tipo+"<br/>" +
						"Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)<br/>" +
						"Sexo: "+vista.getZonaEstSexo()+"<br/>" +
						"Procedencia: "+vista.getZonaEstProcedencia()+"<br/>" +
						"Edad: "+vista.getZonaEstEdad()+"</html>");
				break;
			case "Sexo":
				miResultado = padronConsulta.consultaSexo(-1, -1, zonaEst, vista.getZonaEstProcedencia(),
						vista.getZonaEstEstudios(), vista.getZonaEstEdad());
				vista.setChartConsultaZE(miResultado.getChart());
				vista.setTextoConsultaZE("<html>Zona "+zonaEst+"<br/>" +
						"Distribucin: "+tipo+"<br/>" +
						"Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)<br/>" +
						"Procedencia: "+vista.getZonaEstProcedencia()+"<br/>" +
						"Estudios: "+vista.getZonaEstEstudios()+"<br/>" +
						"Edad: "+vista.getZonaEstEdad()+"</html>");
				break;
			case "Edad":
				miResultado = padronConsulta.consultaEdad(-1, -1, zonaEst, vista.getZonaEstSexo(),
						vista.getZonaEstProcedencia(), vista.getZonaEstEstudios());
				vista.setChartConsultaZE(miResultado.getChart());
				vista.setTextoConsultaZE("<html>Zona "+zonaEst+"<br/>" +
						"Distribucin: "+tipo+"<br/>" +
						"Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)<br/>" +
						"Sexo: "+vista.getZonaEstSexo()+"<br/>" +
						"Procedencia: "+vista.getZonaEstProcedencia()+"<br/>" +
						"Estudios: "+vista.getZonaEstEstudios()+"</html>");
				break;
			default:
			}
		vista.repaint();
		return;
		}
		
		// Si es el botn de Consulta en la pestaa Valladolid (sin divisin)
		if (vista.isValladolidButton(e.getSource())) {		
			String tipo = vista.getTipoConsultaVA();
			ResultadoConsulta miResultado;
			sexoVA = vista.getSexoVA();
			edadVA = vista.getEdadVA();
			procedenciaVA = vista.getProcedenciaVA();
			estudiosVA = vista.getEstudiosVA();
			switch (tipo) {
			case "Procedencia (Nac.)":
				miResultado = padronConsulta.consultaProcedencia(-1, -1, null, sexoVA,
						estudiosVA, edadVA, Padron.TipoProcedencia.NACIONAL);
				vista.setChartConsultaVA(miResultado.getChart());
				vista.setComparaVATipo(tipo);
				vista.setTextoConsultaVA("<html>Distribucin: "+tipo+"<br/>" +
						"Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)<br/>" +
						"Sexo: "+sexoVA+"<br/>" +
						"Estudios: "+estudiosVA+"<br/>" +
						"Edad: "+edadVA+"</html>");
				break;
			case "Procedencia (Extr.)":
				miResultado = padronConsulta.consultaProcedencia(-1, -1, null, sexoVA,
						estudiosVA, edadVA, Padron.TipoProcedencia.EXTRANJERA);
				vista.setChartConsultaVA(miResultado.getChart());
				vista.setComparaVATipo(tipo);
				vista.setTextoConsultaVA("<html>Distribucin: "+tipo+"<br/>" +
						"Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)<br/>" +
						"Sexo: "+sexoVA+"<br/>" +
						"Estudios: "+estudiosVA+"<br/>" +
						"Edad: "+edadVA+"</html>");
				break;
			case "Estudios":
				miResultado = padronConsulta.consultaEstudios(-1, -1, null, sexoVA,
						procedenciaVA, edadVA);
				vista.setChartConsultaVA(miResultado.getChart());
				vista.setComparaVATipo(tipo);
				vista.setTextoConsultaVA("<html>Distribucin: "+tipo+"<br/>" +
						"Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)<br/>" +
						"Sexo: "+sexoVA+"<br/>" +
						"Procedencia: "+procedenciaVA+"<br/>" +
						"Edad: "+edadVA+"</html>");
				break;
			case "Sexo":
				miResultado = padronConsulta.consultaSexo(-1, -1, null, procedenciaVA,
						estudiosVA, edadVA);
				vista.setChartConsultaVA(miResultado.getChart());
				vista.setComparaVATipo(tipo);
				vista.setTextoConsultaVA("<html>Distribucin: "+tipo+"<br/>" +
						"Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)<br/>" +
						"Procedencia: "+procedenciaVA+"<br/>" +
						"Estudios: "+estudiosVA+"<br/>" +
						"Edad: "+edadVA+"</html>");
				break;
			case "Edad":
				miResultado = padronConsulta.consultaEdad(-1, -1, null, sexoVA,
						procedenciaVA, estudiosVA);
				vista.setChartConsultaVA(miResultado.getChart());
				vista.setComparaVATipo(tipo);
				vista.setTextoConsultaVA("<html>Distribucin: "+tipo+"<br/>" +
						"Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)<br/>" +
						"Sexo: "+sexoVA+"<br/>" +
						"Procedencia: "+procedenciaVA+"<br/>" +
						"Estudios: "+estudiosVA+"</html>");
				break;
			default:
			}
		vista.reestableceComparativaVA();
		ulVADto1 = "";
		ulVADto2 = "";
		ulVAZE1 = "";
		ulVAZE2 = "";
		vista.repaint();
		return;
		}
	}

	/**
	 * Captura una modificacin sobre un desplegable. Sirve para disparar una consulta en los casos necesarios.
	 */
	public void itemStateChanged(ItemEvent e) {
		vista.repaint();
		
		// Si se selecciona la opcin por defecto el mtodo no hace nada.
		if (e.getItem().toString().equals("-- Seleccionar --")) {
			vista.repaint();
			return;
		}
		
		// Desplegable de Informacin General de Distrito
		if (vista.isComboGralDto(e.getSource())) {
			
			if (e.getItem().toString().equals(ulDtoinfo)) {
				vista.repaint();
				return;
			}
			ulDtoinfo = e.getItem().toString();
			
			String tipo = vista.getValorComboGralDto();
			ResultadoConsulta miResultado;
			switch (tipo) {
				case "Procedencia (Nac.)":
					miResultado = padronConsulta.consultaProcedencia((vista.getDistritoClicked()+1), -1, null, "Todos", "Todos", "Todos", Padron.TipoProcedencia.NACIONAL);
					vista.setChartCompDto1(miResultado.getChart());
					vista.setComparaDtoActual(vista.getDistritoClicked());
					vista.setComparaDtoTipo(tipo);
					vista.setTextoDatosDto("<html>Distrito "+(vista.getDistritoClicked()+1)+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					vista.setTextoComparaDto("");
					vista.setChartCompDto2(null);
					break;
				case "Procedencia (Extr.)":
					miResultado = padronConsulta.consultaProcedencia((vista.getDistritoClicked()+1), -1, null, "Todos", "Todos", "Todos", Padron.TipoProcedencia.EXTRANJERA);
					vista.setChartCompDto1(miResultado.getChart());
					vista.setComparaDtoActual(vista.getDistritoClicked());
					vista.setComparaDtoTipo(tipo);
					vista.setTextoDatosDto("<html>Distrito "+(vista.getDistritoClicked()+1)+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					vista.setTextoComparaDto("");
					vista.setChartCompDto2(null);
					break;
				case "Estudios":
					miResultado = padronConsulta.consultaEstudios((vista.getDistritoClicked()+1), -1, null, "Todos", "Todos", "Todos");
					vista.setChartCompDto1(miResultado.getChart());
					vista.setComparaDtoActual(vista.getDistritoClicked());
					vista.setComparaDtoTipo(tipo);
					vista.setTextoDatosDto("<html>Distrito "+(vista.getDistritoClicked()+1)+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					vista.setTextoComparaDto("");
					vista.setChartCompDto2(null);
					break;
				case "Sexo":
					miResultado = padronConsulta.consultaSexo((vista.getDistritoClicked()+1), -1, null, "Todos", "Todos", "Todos");
					vista.setChartCompDto1(miResultado.getChart());
					vista.setComparaDtoActual(vista.getDistritoClicked());
					vista.setComparaDtoTipo(tipo);
					vista.setTextoDatosDto("<html>Distrito "+(vista.getDistritoClicked()+1)+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					vista.setTextoComparaDto("");
					vista.setChartCompDto2(null);
					break;
				case "Edad":
					miResultado = padronConsulta.consultaEdad((vista.getDistritoClicked()+1), -1, null, "Todos", "Todos", "Todos");
					vista.setChartCompDto1(miResultado.getChart());
					vista.setComparaDtoActual(vista.getDistritoClicked());
					vista.setComparaDtoTipo(tipo);
					vista.setTextoDatosDto("<html>Distrito "+(vista.getDistritoClicked()+1)+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					vista.setTextoComparaDto("");
					vista.setChartCompDto2(null);
					break;
				case "-- Seleccionar --":
					vista.repaint();
					return;
				default:
					vista.repaint();
					return;
			}
			vista.repaint();
			ulDtocomp = "";
			return;
		}
		
		// Desplegable de Comparativa de Distrito
		if (vista.isComboComparaDto(e.getSource())) {
			
			if (e.getItem().toString().equals(ulDtocomp)) {
				vista.repaint();
				return;
			}
			ulDtocomp = e.getItem().toString();
			
			int dtoCompara = 0;
			switch (e.getItem().toString()) {
			case "Distrito 1":
				dtoCompara = 1;
				break;
			case "Distrito 2":
				dtoCompara = 2;
				break;
			case "Distrito 3":
				dtoCompara = 3;
				break;
			case "Distrito 4":
				dtoCompara = 4;
				break;
			case "Distrito 5":
				dtoCompara = 5;
				break;
			case "Distrito 6":
				dtoCompara = 6;
				break;
			case "Distrito 7":
				dtoCompara = 7;
				break;
			case "Distrito 8":
				dtoCompara = 8;
				break;
			case "Distrito 9":
				dtoCompara = 9;
				break;
			case "Distrito 10":
				dtoCompara = 10;
				break;
			case "Distrito 11":
				dtoCompara = 11;
				break;
			case "Distrito 12":
				dtoCompara = 12;
				break;
			}
			String tipo = vista.getComparaDtoTipo();
			ResultadoConsulta miResultado;
			switch (tipo) {
				case "Procedencia (Nac.)":
					miResultado = padronConsulta.consultaProcedencia(dtoCompara, -1, null, "Todos", "Todos", "Todos", Padron.TipoProcedencia.NACIONAL);
					vista.setChartCompDto2(miResultado.getChart());
					vista.setTextoComparaDto("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "Procedencia (Extr.)":
					miResultado = padronConsulta.consultaProcedencia(dtoCompara, -1, null, "Todos", "Todos", "Todos", Padron.TipoProcedencia.EXTRANJERA);
					vista.setChartCompDto2(miResultado.getChart());
					vista.setTextoComparaDto("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "Estudios":
					miResultado = padronConsulta.consultaEstudios(dtoCompara, -1, null, "Todos", "Todos", "Todos");
					vista.setChartCompDto2(miResultado.getChart());
					vista.setTextoComparaDto("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "Sexo":
					miResultado = padronConsulta.consultaSexo(dtoCompara, -1, null, "Todos", "Todos", "Todos");
					vista.setChartCompDto2(miResultado.getChart());
					vista.setTextoComparaDto("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "Edad":
					miResultado = padronConsulta.consultaEdad(dtoCompara, -1, null, "Todos", "Todos", "Todos");
					vista.setChartCompDto2(miResultado.getChart());
					vista.setTextoComparaDto("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "-- Seleccionar --":
					vista.repaint();
					return;
				default:
					vista.repaint();
					return;
			}
			vista.repaint();
			return;
		}
		
		// Desplegable de Informacin General de Zona Estadstica
		if (vista.isComboGralZE(e.getSource())) {
			
			if (e.getItem().toString().equals(ulZEinfo)) {
				vista.repaint();
				return;
			}
			ulZEinfo = e.getItem().toString();
			
			String tipo = vista.getValorComboGralZE();
			ResultadoConsulta miResultado;
			String zonaEst = null;
			switch (vista.getZonaEstClicked()+1) {
			case 43:
				zonaEst = "8B";
				break;
			case 44:
				zonaEst = "12B";
				break;
			case 45:
				zonaEst = "15B";
				break;
			case 46:
				zonaEst = "24B";
				break;
			case 47:
				zonaEst = "36B";
				break;
			default:
				zonaEst = Integer.toString(vista.getZonaEstClicked()+1);
			}
			switch (tipo) {
				case "Procedencia (Nac.)":
					miResultado = padronConsulta.consultaProcedencia(-1, -1, zonaEst, "Todos", "Todos", "Todos", Padron.TipoProcedencia.NACIONAL);
					vista.setChartCompZE1(miResultado.getChart());
					vista.setComparaZEActual(vista.getZonaEstClicked());
					vista.setComparaZETipo(tipo);
					vista.setTextoDatosZE("<html>Zona "+zonaEst+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					vista.setTextoComparaZE("");
					vista.setChartCompZE2(null);
					break;
				case "Procedencia (Extr.)":
					miResultado = padronConsulta.consultaProcedencia(-1, -1, zonaEst, "Todos", "Todos", "Todos", Padron.TipoProcedencia.EXTRANJERA);
					vista.setChartCompZE1(miResultado.getChart());
					vista.setComparaZEActual(vista.getZonaEstClicked());
					vista.setComparaZETipo(tipo);
					vista.setTextoDatosZE("<html>Zona "+zonaEst+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					vista.setTextoComparaZE("");
					vista.setChartCompZE2(null);
					break;
				case "Estudios":
					miResultado = padronConsulta.consultaEstudios(-1, -1, zonaEst, "Todos", "Todos", "Todos");
					vista.setChartCompZE1(miResultado.getChart());
					vista.setComparaZEActual(vista.getZonaEstClicked());
					vista.setComparaZETipo(tipo);
					vista.setTextoDatosZE("<html>Zona "+zonaEst+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					vista.setTextoComparaZE("");
					vista.setChartCompZE2(null);
					break;
				case "Sexo":
					miResultado = padronConsulta.consultaSexo(-1, -1, zonaEst, "Todos", "Todos", "Todos");
					vista.setChartCompZE1(miResultado.getChart());
					vista.setComparaZEActual(vista.getZonaEstClicked());
					vista.setComparaZETipo(tipo);
					vista.setTextoDatosZE("<html>Zona "+zonaEst+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					vista.setTextoComparaZE("");
					vista.setChartCompZE2(null);
					break;
				case "Edad":
					miResultado = padronConsulta.consultaEdad(-1, -1, zonaEst, "Todos", "Todos", "Todos");
					vista.setChartCompZE1(miResultado.getChart());
					vista.setComparaZEActual(vista.getZonaEstClicked());
					vista.setComparaZETipo(tipo);
					vista.setTextoDatosZE("<html>Zona "+zonaEst+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					vista.setTextoComparaZE("");
					vista.setChartCompZE2(null);
					break;
				case "-- Seleccionar --":
					return;
				default:
					vista.repaint();
					return;
			}
			vista.repaint();
			ulDtocomp = "";
			return;
		}
		
		// Desplegable de Comparativa de Zona Estadstica
		if (vista.isComboComparaZE(e.getSource())) {

			if (e.getItem().toString().equals(ulZEcomp)) {
				vista.repaint();
				return;
			}
			ulZEcomp = e.getItem().toString();
			
			String zeCompara = null;
			switch ((String)e.getItem()) {
			case "Zona 1":
				zeCompara = "1";
				break;
			case "Zona 2":
				zeCompara = "2";
				break;
			case "Zona 3":
				zeCompara = "3";
				break;
			case "Zona 4":
				zeCompara = "4";
				break;
			case "Zona 5":
				zeCompara = "5";
				break;
			case "Zona 6":
				zeCompara = "6";
				break;
			case "Zona 7":
				zeCompara = "7";
				break;
			case "Zona 8":
				zeCompara = "8";
				break;
			case "Zona 9":
				zeCompara = "9";
				break;
			case "Zona 10":
				zeCompara = "10";
				break;
			case "Zona 11":
				zeCompara = "11";
				break;
			case "Zona 12":
				zeCompara = "12";
				break;
			case "Zona 13":
				zeCompara = "13";
				break;
			case "Zona 14":
				zeCompara = "14";
				break;
			case "Zona 15":
				zeCompara = "15";
				break;
			case "Zona 16":
				zeCompara = "16";
				break;
			case "Zona 17":
				zeCompara = "17";
				break;
			case "Zona 18":
				zeCompara = "18";
				break;
			case "Zona 19":
				zeCompara = "19";
				break;
			case "Zona 20":
				zeCompara = "20";
				break;
			case "Zona 21":
				zeCompara = "21";
				break;
			case "Zona 22":
				zeCompara = "22";
				break;
			case "Zona 23":
				zeCompara = "23";
				break;
			case "Zona 24":
				zeCompara = "24";
				break;
			case "Zona 25":
				zeCompara = "25";
				break;
			case "Zona 26":
				zeCompara = "26";
				break;
			case "Zona 27":
				zeCompara = "27";
				break;
			case "Zona 28":
				zeCompara = "28";
				break;
			case "Zona 29":
				zeCompara = "29";
				break;
			case "Zona 30":
				zeCompara = "30";
				break;
			case "Zona 31":
				zeCompara = "31";
				break;
			case "Zona 32":
				zeCompara = "32";
				break;
			case "Zona 33":
				zeCompara = "33";
				break;
			case "Zona 34":
				zeCompara = "34";
				break;
			case "Zona 35":
				zeCompara = "35";
				break;
			case "Zona 36":
				zeCompara = "36";
				break;
			case "Zona 37":
				zeCompara = "37";
				break;
			case "Zona 38":
				zeCompara = "38";
				break;
			case "Zona 39":
				zeCompara = "39";
				break;
			case "Zona 40":
				zeCompara = "40";
				break;
			case "Zona 41":
				zeCompara = "41";
				break;
			case "Zona 42":
				zeCompara = "42";
				break;
			case "Zona 8B":
				zeCompara = "8B";
				break;
			case "Zona 12B":
				zeCompara = "12B";
				break;
			case "Zona 15B":
				zeCompara = "15B";
				break;
			case "Zona 24B":
				zeCompara = "24B";
				break;
			case "Zona 36B":
				zeCompara = "36B";
				break;
			}
			String tipo = vista.getComparaZETipo();
			ResultadoConsulta miResultado;
			switch (tipo) {
				case "Procedencia (Nac.)":
					miResultado = padronConsulta.consultaProcedencia(-1, -1, zeCompara, "Todos", "Todos", "Todos", Padron.TipoProcedencia.NACIONAL);
					vista.setChartCompZE2(miResultado.getChart());
					vista.setTextoComparaZE("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "Procedencia (Extr.)":
					miResultado = padronConsulta.consultaProcedencia(-1, -1, zeCompara, "Todos", "Todos", "Todos", Padron.TipoProcedencia.EXTRANJERA);
					vista.setChartCompZE2(miResultado.getChart());
					vista.setTextoComparaZE("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "Estudios":
					miResultado = padronConsulta.consultaEstudios(-1, -1, zeCompara, "Todos", "Todos", "Todos");
					vista.setChartCompZE2(miResultado.getChart());
					vista.setTextoComparaZE("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "Sexo":
					miResultado = padronConsulta.consultaSexo(-1, -1, zeCompara, "Todos", "Todos", "Todos");
					vista.setChartCompZE2(miResultado.getChart());
					vista.setTextoComparaZE("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "Edad":
					miResultado = padronConsulta.consultaEdad(-1, -1, zeCompara, "Todos", "Todos", "Todos");
					vista.setChartCompZE2(miResultado.getChart());
					vista.setTextoComparaZE("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "-- Seleccionar --":
					vista.repaint();
					return;
				default:
					vista.repaint();
					return;
			}
			vista.repaint();
			return;
		}
		
		// Desplegable superior de Comparativa de Valladolid con Distrito
		if (vista.isComboComparaDto1VA(e.getSource())) {

			if (e.getItem().toString().equals(ulVADto1)) {
				vista.repaint();
				return;
			}
			ulVADto1 = e.getItem().toString();
			
			int dtoCompara = 0;
			switch (e.getItem().toString()) {
			case "Distrito 1":
				dtoCompara = 1;
				break;
			case "Distrito 2":
				dtoCompara = 2;
				break;
			case "Distrito 3":
				dtoCompara = 3;
				break;
			case "Distrito 4":
				dtoCompara = 4;
				break;
			case "Distrito 5":
				dtoCompara = 5;
				break;
			case "Distrito 6":
				dtoCompara = 6;
				break;
			case "Distrito 7":
				dtoCompara = 7;
				break;
			case "Distrito 8":
				dtoCompara = 8;
				break;
			case "Distrito 9":
				dtoCompara = 9;
				break;
			case "Distrito 10":
				dtoCompara = 10;
				break;
			case "Distrito 11":
				dtoCompara = 11;
				break;
			case "Distrito 12":
				dtoCompara = 12;
				break;
			}
			String tipo = vista.getComparaVATipo();
			ResultadoConsulta miResultado;
			switch (tipo) {
				case "Procedencia (Nac.)":
					miResultado = padronConsulta.consultaProcedencia(dtoCompara, -1, null, sexoVA, estudiosVA, edadVA, Padron.TipoProcedencia.NACIONAL);
					vista.setChartSupVA(miResultado.getChart());
					vista.setTextoSupVA("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "Procedencia (Extr.)":
					miResultado = padronConsulta.consultaProcedencia(dtoCompara, -1, null, sexoVA, estudiosVA, edadVA, Padron.TipoProcedencia.EXTRANJERA);
					vista.setChartSupVA(miResultado.getChart());
					vista.setTextoSupVA("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "Estudios":
					miResultado = padronConsulta.consultaEstudios(dtoCompara, -1, null, sexoVA, procedenciaVA, edadVA);
					vista.setChartSupVA(miResultado.getChart());
					vista.setTextoSupVA("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "Sexo":
					miResultado = padronConsulta.consultaSexo(dtoCompara, -1, null, procedenciaVA, estudiosVA, edadVA);
					vista.setChartSupVA(miResultado.getChart());
					vista.setTextoSupVA("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "Edad":
					miResultado = padronConsulta.consultaEdad(dtoCompara, -1, null, sexoVA, procedenciaVA, estudiosVA);
					vista.setChartSupVA(miResultado.getChart());
					vista.setTextoSupVA("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "-- Seleccionar --":
					vista.repaint();
					return;
				default:
					vista.repaint();
					return;
			}
			vista.repaint();
			return;
		}
		
		// Desplegable inferior de Comparativa de Valladolid con Distrito
		if (vista.isComboComparaDto2VA(e.getSource())) {

			if (e.getItem().toString().equals(ulVADto2)) {
				vista.repaint();
				return;
			}
			ulVADto2 = e.getItem().toString();
			
			int dtoCompara = 0;
			switch (e.getItem().toString()) {
			case "Distrito 1":
				dtoCompara = 1;
				break;
			case "Distrito 2":
				dtoCompara = 2;
				break;
			case "Distrito 3":
				dtoCompara = 3;
				break;
			case "Distrito 4":
				dtoCompara = 4;
				break;
			case "Distrito 5":
				dtoCompara = 5;
				break;
			case "Distrito 6":
				dtoCompara = 6;
				break;
			case "Distrito 7":
				dtoCompara = 7;
				break;
			case "Distrito 8":
				dtoCompara = 8;
				break;
			case "Distrito 9":
				dtoCompara = 9;
				break;
			case "Distrito 10":
				dtoCompara = 10;
				break;
			case "Distrito 11":
				dtoCompara = 11;
				break;
			case "Distrito 12":
				dtoCompara = 12;
				break;
			}
			String tipo = vista.getComparaVATipo();
			ResultadoConsulta miResultado;
			switch (tipo) {
				case "Procedencia (Nac.)":
					miResultado = padronConsulta.consultaProcedencia(dtoCompara, -1, null, sexoVA, estudiosVA, edadVA, Padron.TipoProcedencia.NACIONAL);
					vista.setChartInfVA(miResultado.getChart());
					vista.setTextoInfVA("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "Procedencia (Extr.)":
					miResultado = padronConsulta.consultaProcedencia(dtoCompara, -1, null, sexoVA, estudiosVA, edadVA, Padron.TipoProcedencia.EXTRANJERA);
					vista.setChartInfVA(miResultado.getChart());
					vista.setTextoInfVA("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "Estudios":
					miResultado = padronConsulta.consultaEstudios(dtoCompara, -1, null, sexoVA, procedenciaVA, edadVA);
					vista.setChartInfVA(miResultado.getChart());
					vista.setTextoInfVA("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "Sexo":
					miResultado = padronConsulta.consultaSexo(dtoCompara, -1, null, procedenciaVA, estudiosVA, edadVA);
					vista.setChartInfVA(miResultado.getChart());
					vista.setTextoInfVA("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "Edad":
					miResultado = padronConsulta.consultaEdad(dtoCompara, -1, null, sexoVA, procedenciaVA, estudiosVA);
					vista.setChartInfVA(miResultado.getChart());
					vista.setTextoInfVA("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "-- Seleccionar --":
					vista.repaint();
					return;
				default:
					vista.repaint();
					return;
			}
			vista.repaint();
			return;
		}

		// Desplegable inferior de Comparativa de Valladolid con Zona Estadstica
		if (vista.isComboComparaZE2VA(e.getSource())) {

			if (e.getItem().toString().equals(ulVAZE2)) {
				vista.repaint();
				return;
			}
			ulVAZE2 = e.getItem().toString();

			String zeCompara = null;
			switch ((String)e.getItem()) {
			case "Zona 1":
				zeCompara = "1";
				break;
			case "Zona 2":
				zeCompara = "2";
				break;
			case "Zona 3":
				zeCompara = "3";
				break;
			case "Zona 4":
				zeCompara = "4";
				break;
			case "Zona 5":
				zeCompara = "5";
				break;
			case "Zona 6":
				zeCompara = "6";
				break;
			case "Zona 7":
				zeCompara = "7";
				break;
			case "Zona 8":
				zeCompara = "8";
				break;
			case "Zona 9":
				zeCompara = "9";
				break;
			case "Zona 10":
				zeCompara = "10";
				break;
			case "Zona 11":
				zeCompara = "11";
				break;
			case "Zona 12":
				zeCompara = "12";
				break;
			case "Zona 13":
				zeCompara = "13";
				break;
			case "Zona 14":
				zeCompara = "14";
				break;
			case "Zona 15":
				zeCompara = "15";
				break;
			case "Zona 16":
				zeCompara = "16";
				break;
			case "Zona 17":
				zeCompara = "17";
				break;
			case "Zona 18":
				zeCompara = "18";
				break;
			case "Zona 19":
				zeCompara = "19";
				break;
			case "Zona 20":
				zeCompara = "20";
				break;
			case "Zona 21":
				zeCompara = "21";
				break;
			case "Zona 22":
				zeCompara = "22";
				break;
			case "Zona 23":
				zeCompara = "23";
				break;
			case "Zona 24":
				zeCompara = "24";
				break;
			case "Zona 25":
				zeCompara = "25";
				break;
			case "Zona 26":
				zeCompara = "26";
				break;
			case "Zona 27":
				zeCompara = "27";
				break;
			case "Zona 28":
				zeCompara = "28";
				break;
			case "Zona 29":
				zeCompara = "29";
				break;
			case "Zona 30":
				zeCompara = "30";
				break;
			case "Zona 31":
				zeCompara = "31";
				break;
			case "Zona 32":
				zeCompara = "32";
				break;
			case "Zona 33":
				zeCompara = "33";
				break;
			case "Zona 34":
				zeCompara = "34";
				break;
			case "Zona 35":
				zeCompara = "35";
				break;
			case "Zona 36":
				zeCompara = "36";
				break;
			case "Zona 37":
				zeCompara = "37";
				break;
			case "Zona 38":
				zeCompara = "38";
				break;
			case "Zona 39":
				zeCompara = "39";
				break;
			case "Zona 40":
				zeCompara = "40";
				break;
			case "Zona 41":
				zeCompara = "41";
				break;
			case "Zona 42":
				zeCompara = "42";
				break;
			case "Zona 8B":
				zeCompara = "8B";
				break;
			case "Zona 12B":
				zeCompara = "12B";
				break;
			case "Zona 15B":
				zeCompara = "15B";
				break;
			case "Zona 24B":
				zeCompara = "24B";
				break;
			case "Zona 36B":
				zeCompara = "36B";
				break;
			}
			String tipo = vista.getComparaVATipo();
			ResultadoConsulta miResultado;
			switch (tipo) {
				case "Procedencia (Nac.)":
					miResultado = padronConsulta.consultaProcedencia(-1, -1, zeCompara, sexoVA, estudiosVA, edadVA, Padron.TipoProcedencia.NACIONAL);
					vista.setChartInfVA(miResultado.getChart());
					vista.setTextoInfVA("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "Procedencia (Extr.)":
					miResultado = padronConsulta.consultaProcedencia(-1, -1, zeCompara, sexoVA, estudiosVA, edadVA, Padron.TipoProcedencia.EXTRANJERA);
					vista.setChartInfVA(miResultado.getChart());
					vista.setTextoInfVA("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "Estudios":
					miResultado = padronConsulta.consultaEstudios(-1, -1, zeCompara, sexoVA, procedenciaVA, edadVA);
					vista.setChartInfVA(miResultado.getChart());
					vista.setTextoInfVA("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "Sexo":
					miResultado = padronConsulta.consultaSexo(-1, -1, zeCompara, procedenciaVA, estudiosVA, edadVA);
					vista.setChartInfVA(miResultado.getChart());
					vista.setTextoInfVA("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "Edad":
					miResultado = padronConsulta.consultaEdad(-1, -1, zeCompara, sexoVA, procedenciaVA, estudiosVA);
					vista.setChartInfVA(miResultado.getChart());
					vista.setTextoInfVA("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "-- Seleccionar --":
					vista.repaint();
					return;
				default:
					vista.repaint();
					return;
			}
			vista.repaint();
			return;
		}
		
		// Desplegable superior de Comparativa de Valladolid con Zona Estadstica
		if (vista.isComboComparaZE1VA(e.getSource())) {
			
			if (e.getItem().toString().equals(ulVAZE1)) {
				vista.repaint();
				return;
			}
			ulVAZE1 = e.getItem().toString();

			String zeCompara = null;
			switch ((String)e.getItem()) {
			case "Zona 1":
				zeCompara = "1";
				break;
			case "Zona 2":
				zeCompara = "2";
				break;
			case "Zona 3":
				zeCompara = "3";
				break;
			case "Zona 4":
				zeCompara = "4";
				break;
			case "Zona 5":
				zeCompara = "5";
				break;
			case "Zona 6":
				zeCompara = "6";
				break;
			case "Zona 7":
				zeCompara = "7";
				break;
			case "Zona 8":
				zeCompara = "8";
				break;
			case "Zona 9":
				zeCompara = "9";
				break;
			case "Zona 10":
				zeCompara = "10";
				break;
			case "Zona 11":
				zeCompara = "11";
				break;
			case "Zona 12":
				zeCompara = "12";
				break;
			case "Zona 13":
				zeCompara = "13";
				break;
			case "Zona 14":
				zeCompara = "14";
				break;
			case "Zona 15":
				zeCompara = "15";
				break;
			case "Zona 16":
				zeCompara = "16";
				break;
			case "Zona 17":
				zeCompara = "17";
				break;
			case "Zona 18":
				zeCompara = "18";
				break;
			case "Zona 19":
				zeCompara = "19";
				break;
			case "Zona 20":
				zeCompara = "20";
				break;
			case "Zona 21":
				zeCompara = "21";
				break;
			case "Zona 22":
				zeCompara = "22";
				break;
			case "Zona 23":
				zeCompara = "23";
				break;
			case "Zona 24":
				zeCompara = "24";
				break;
			case "Zona 25":
				zeCompara = "25";
				break;
			case "Zona 26":
				zeCompara = "26";
				break;
			case "Zona 27":
				zeCompara = "27";
				break;
			case "Zona 28":
				zeCompara = "28";
				break;
			case "Zona 29":
				zeCompara = "29";
				break;
			case "Zona 30":
				zeCompara = "30";
				break;
			case "Zona 31":
				zeCompara = "31";
				break;
			case "Zona 32":
				zeCompara = "32";
				break;
			case "Zona 33":
				zeCompara = "33";
				break;
			case "Zona 34":
				zeCompara = "34";
				break;
			case "Zona 35":
				zeCompara = "35";
				break;
			case "Zona 36":
				zeCompara = "36";
				break;
			case "Zona 37":
				zeCompara = "37";
				break;
			case "Zona 38":
				zeCompara = "38";
				break;
			case "Zona 39":
				zeCompara = "39";
				break;
			case "Zona 40":
				zeCompara = "40";
				break;
			case "Zona 41":
				zeCompara = "41";
				break;
			case "Zona 42":
				zeCompara = "42";
				break;
			case "Zona 8B":
				zeCompara = "8B";
				break;
			case "Zona 12B":
				zeCompara = "12B";
				break;
			case "Zona 15B":
				zeCompara = "15B";
				break;
			case "Zona 24B":
				zeCompara = "24B";
				break;
			case "Zona 36B":
				zeCompara = "36B";
				break;
			}
			String tipo = vista.getComparaVATipo();
			ResultadoConsulta miResultado;
			switch (tipo) {
				case "Procedencia (Nac.)":
					miResultado = padronConsulta.consultaProcedencia(-1, -1, zeCompara, sexoVA, estudiosVA, edadVA, Padron.TipoProcedencia.NACIONAL);
					vista.setChartSupVA(miResultado.getChart());
					vista.setTextoSupVA("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "Procedencia (Extr.)":
					miResultado = padronConsulta.consultaProcedencia(-1, -1, zeCompara, sexoVA, estudiosVA, edadVA, Padron.TipoProcedencia.EXTRANJERA);
					vista.setChartSupVA(miResultado.getChart());
					vista.setTextoSupVA("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "Estudios":
					miResultado = padronConsulta.consultaEstudios(-1, -1, zeCompara, sexoVA, procedenciaVA, edadVA);
					vista.setChartSupVA(miResultado.getChart());
					vista.setTextoSupVA("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "Sexo":
					miResultado = padronConsulta.consultaSexo(-1, -1, zeCompara, procedenciaVA, estudiosVA, edadVA);
					vista.setChartSupVA(miResultado.getChart());
					vista.setTextoSupVA("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "Edad":
					miResultado = padronConsulta.consultaEdad(-1, -1, zeCompara, sexoVA, procedenciaVA, estudiosVA);
					vista.setChartSupVA(miResultado.getChart());
					vista.setTextoSupVA("<html>"+e.getItem().toString()+". Poblacin: "+miResultado.getPoblacionConsulta()+" ("+formateador.format(miResultado.getPorcentaje())+"%)</html>");
					break;
				case "-- Seleccionar --":
					vista.repaint();
					return;
				default:
					vista.repaint();
					return;
			}
			vista.repaint();
			return;
		}
	}
}
