package negocio;

import org.jfree.chart.JFreeChart;

/**
 * Clase que almacena la grfica, poblacin representada, porcentaje respecto al total y poblacin total
 * resultado de una consulta
 * 
 * @author Santiago de la Parte Flrez
 */
public class ResultadoConsulta {
	
	// Elementos de la clase
	private double porcentaje = -1.99;
	private int poblacionConsulta = -1;
	private int poblacion = -1;
	private JFreeChart chart = null;
	
	/**
	 * Devuelve la poblacin representada en la consulta.
	 * 
	 * @return Integer con la poblacin representada en la consulta.
	 */
	public int getPoblacionConsulta() {
		return poblacionConsulta;
	}

	/**
	 * Asigna la poblacin representada en la consulta.
	 * 
	 * @param poblacionConsulta Integer con la poblacin representada en la consulta.
	 */
	protected void setPoblacionConsulta(int poblacionConsulta) {
		this.poblacionConsulta = poblacionConsulta;
	}

	/**
	 * Asigna la grfica de la consulta.
	 * 
	 * @param chart JFreeChart con la grfica de la consulta.
	 */
	protected void setChart (JFreeChart chart) {
		this.chart = chart;
	}
	
	/**
	 * Asigna la poblacin total.
	 * 
	 * @param poblacion Integer con la poblacin total.
	 */
	protected void setPoblacion(int poblacion) {
		this.poblacion = poblacion;
	}

	/**
	 * Devuelve la grfica de la consulta.
	 * 
	 * @return JFreeChart con la grfica de la consulta.
	 */
	public JFreeChart getChart() {
		return chart;
	}
	
	/**
	 * Devuelve el porcentaje de poblacin representado en la consulta.
	 * 
	 * @return Double con el porcentaje de poblacin representado en la consulta.
	 */
	public double getPorcentaje() {
		if (porcentaje==-1.99) {
			porcentaje = ((double)poblacionConsulta*100/(double)poblacion);
		}
		return porcentaje;
	}
	
	/**
	 * Devuelve la poblacin total.
	 * 
	 * @return Integer con la poblacin total.
	 */
	public int getPoblacion() {
		return poblacion;
	}
}
