package presentacion;

import java.awt.AlphaComposite;
import java.awt.Color;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Polygon;
import java.awt.RenderingHints;

import javax.swing.JPanel;

/**
 * Clase para representar un mapa de polgonos clickables.
 * 
 * @author Santiago de la Parte
 */
class PolygonPanel extends JPanel {  

	private static final long serialVersionUID = 1L;
	
	private Polygon[] polygons;
    private int clicked = -1; //Polgono actual (clic)
    private int encima = -1; //Polgono activo (raton encima)
    private Color[] colors; //Colores para los distritos
    
    private boolean creado = false;

    /**
     * Creacin.
     * 
     * @param poligonos Array de polgonos.
     * @param colores Array de colores para los polgonos.
     */
    public PolygonPanel(Polygon[] poligonos, Color[] colores) {
		this.polygons = poligonos;
		this.colors = colores;
    	setOpaque(false);
    	this.creado = true;
	}  
   
    /**
     * Colorea los polgonos de la clase. Mtodo heredado.
     * 
     * @param g
     */
	protected void paintComponent(Graphics g) {
    	super.paintComponent(g);
        if (!creado)
        	return;
        Graphics2D g2 = (Graphics2D)g;  
        g2.setRenderingHint(RenderingHints.KEY_INTERPOLATION, RenderingHints.VALUE_INTERPOLATION_BILINEAR);
        g2.setComposite(AlphaComposite.SrcOver.derive(0.2f));
        coloreaNoActivos(g2);
        if ((clicked != -1)) {
        	g2.setPaint(Color.RED);
        	g2.fill(polygons[clicked]);
            g2.drawPolygon(polygons[clicked]);
        }
        
        if ((encima != -1) && (clicked != encima)) {      	
        	g2.setPaint(new Color(Integer.parseInt("66ff00", 16)));
            g2.fill(polygons[encima]);
            g2.drawPolygon(polygons[encima]);
        }
    }  

	/**
	 * Asigna el ndice del polgono seleccionado.
	 * 
	 * @param i ndice del polgono seleccionado.
	 */
    public void setClicked(int i) {
    	clicked = i;
    }
    
    /**
     * Asigna el ndice del polgono sobre el que est situado el ratn.
     * 
     * @param i ndice sobre el que est situado el ratn.
     */
    public void setEncima(int i) {
    	encima = i;
    }
    
    /**
     * Devuelve el ndice del polgono seleccionado.
     * 
     * @return ndice del polgono seleccionado.
     */
    public int getClicked() {
    	return clicked;
    }
    
    /**
     * Devuelve el ndice del polgono sobre el que est situado el ratn.
     * 
     * @return ndice sobre el que est situado el ratn.
     */
    protected int getEncima() {
    	return encima;
    }
    
    /**
     * Colorea los polgonos no activos (seleccionados o con el ratn encima) con los colores
     * por defecto.
     * 
     * @param g2
     */
    private void coloreaNoActivos(Graphics2D g2) {
    	for (int i=0; i<polygons.length; i++) {
    		// Aquellos en los que estoy encima o estn clicados no son coloreados
    		if ((i == encima) | (i == clicked))
    				continue;
    		g2.setPaint(colors[i]);
    		g2.fill(polygons[i]);
    		g2.drawPolygon(polygons[i]);
    	}
    }
}
